@@ -36,7 +36,7 @@
  * the terms of any one of the MPL, the GPL or the LGPL.
  *
  * ***** END LICENSE BLOCK ***** */
-/* $Id: nss.h,v 1.46.2.8 2006/09/08 23:55:05 wtchang%redhat.com Exp $ */
+/* $Id: nss.h,v 1.46.2.15 2007/02/14 23:39:26 christophe.ravel.bugs%sun.com Exp $ */
 
 #ifndef __nss_h_
 #define __nss_h_
@@ -45,25 +45,28 @@
 
 SEC_BEGIN_PROTOS
 
+/* The private macro _NSS_ECC_STRING is for NSS internal use only. */
+#ifdef NSS_ENABLE_ECC
+#ifdef NSS_ECC_MORE_THAN_SUITE_B
+#define _NSS_ECC_STRING " Extended ECC"
+#else
+#define _NSS_ECC_STRING " Basic ECC"
+#endif
+#else
+#define _NSS_ECC_STRING ""
+#endif
+
 /*
  * NSS's major version, minor version, patch level, and whether
  * this is a beta release.
  *
  * The format of the version string should be
- *     "<major version>.<minor version>[.<patch level>] [<Beta>]"
+ *     "<major version>.<minor version>[.<patch level>][ <ECC>][ <Beta>]"
  */
-#ifdef NSS_ENABLE_ECC
-#ifdef NSS_ECC_MORE_THAN_SUITE_B
-#define NSS_VERSION  "3.11.3 Extended ECC"
-#else
-#define NSS_VERSION  "3.11.3 Basic ECC"
-#endif
-#else
-#define NSS_VERSION  "3.11.3"
-#endif
+#define NSS_VERSION  "3.11.6" _NSS_ECC_STRING
 #define NSS_VMAJOR   3
 #define NSS_VMINOR   11
-#define NSS_VPATCH   3
+#define NSS_VPATCH   6
 #define NSS_BETA     PR_FALSE
 
 /*
